@@ -1,16 +1,65 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="ru">
+<context>
+    <name>brightness_small</name>
+    <message>
+        <location filename="../brightness_small.ui" line="14"/>
+        <source>MainWindow</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="39"/>
+        <source>Save</source>
+        <translation type="unfinished">Сохранить</translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="59"/>
+        <source>Software (xrandr) Brightness</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="66"/>
+        <location filename="../brightness_small.ui" line="87"/>
+        <source>TextLabel</source>
+        <translation type="unfinished">TextLabel</translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="80"/>
+        <source>Hardware Backlight</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="94"/>
+        <source>&gt;&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.cpp" line="23"/>
+        <source>MX-Tweak</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.cpp" line="49"/>
+        <source>Display</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.cpp" line="54"/>
+        <source>&amp;Quit</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>defaultlook</name>
     <message>
         <location filename="../defaultlook.ui" line="20"/>
-        <location filename="../defaultlook.cpp" line="58"/>
-        <location filename="../defaultlook.cpp" line="527"/>
-        <location filename="../defaultlook.cpp" line="534"/>
-        <location filename="../defaultlook.cpp" line="551"/>
-        <location filename="../defaultlook.cpp" line="562"/>
-        <location filename="../defaultlook.cpp" line="572"/>
+        <location filename="../defaultlook.cpp" line="62"/>
+        <location filename="../defaultlook.cpp" line="536"/>
+        <location filename="../defaultlook.cpp" line="543"/>
+        <location filename="../defaultlook.cpp" line="560"/>
+        <location filename="../defaultlook.cpp" line="571"/>
+        <location filename="../defaultlook.cpp" line="581"/>
         <source>MX Tweak</source>
         <translation>MX Tweak</translation>
     </message>
@@ -145,7 +194,10 @@
         <location filename="../defaultlook.ui" line="549"/>
         <location filename="../defaultlook.ui" line="740"/>
         <location filename="../defaultlook.ui" line="894"/>
-        <location filename="../defaultlook.ui" line="936"/>
+        <location filename="../defaultlook.ui" line="974"/>
+        <location filename="../defaultlook.ui" line="1097"/>
+        <location filename="../defaultlook.ui" line="1104"/>
+        <location filename="../defaultlook.ui" line="1141"/>
         <source>Apply</source>
         <translation>Применить</translation>
     </message>
@@ -187,12 +239,13 @@
     <message>
         <location filename="../defaultlook.ui" line="589"/>
         <source>Remove User Theme Set</source>
-        <translation type="unfinished"></translation>
+        <oldsource>Remove User Theme Sets</oldsource>
+        <translation>Удалить пользовательскую настройку темы</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="600"/>
         <source>Save Current Settings as a Theme Set</source>
-        <translation type="unfinished"></translation>
+        <translation>Сохранить текущие настройки как набор тем</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="614"/>
@@ -200,16 +253,6 @@
         <source>Compositor</source>
         <translation>Композитор</translation>
     </message>
-    <message>
-        <location filename="../defaultlook.ui" line="635"/>
-        <source>Launch compton-conf configuration tool</source>
-        <translation>Запустить конфигуратор compton-conf</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="638"/>
-        <source>Compton settings</source>
-        <translation>Настройки Compton</translation>
-    </message>
     <message>
         <location filename="../defaultlook.ui" line="662"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
@@ -250,15 +293,25 @@
         <source>Transparency and shadow options</source>
         <translation>Параметры прозрачности и теней</translation>
     </message>
+    <message>
+        <location filename="../defaultlook.ui" line="635"/>
+        <source>Launch compton-conf configuration tool</source>
+        <translation>Запустить конфигуратор compton-conf</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="638"/>
+        <source>Compton settings</source>
+        <translation>Настройки Compton</translation>
+    </message>
     <message>
         <location filename="../defaultlook.ui" line="774"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Изменение режима VBlank может смягчить некоторые проблемы тиринга. Для подробностей, смотрите Справку.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="777"/>
         <source>VBlank</source>
-        <translation type="unfinished"></translation>
+        <translation>VBlank</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="785"/>
@@ -268,12 +321,12 @@
     <message>
         <location filename="../defaultlook.ui" line="790"/>
         <source>glx</source>
-        <translation type="unfinished"></translation>
+        <translation>glx</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="795"/>
         <source>xpresent</source>
-        <translation type="unfinished"></translation>
+        <translation>xpresent</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="800"/>
@@ -327,106 +380,158 @@
     </message>
     <message>
         <location filename="../defaultlook.ui" line="908"/>
+        <source>Display</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="933"/>
+        <source>Hardware Backlight</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="940"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="967"/>
+        <source>Choose Display for xrandr tweaks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1000"/>
+        <source>Resolution</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1007"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1010"/>
+        <source>Save</source>
+        <translation>Сохранить</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1017"/>
+        <source>Software (xrandr) Brightness</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1024"/>
+        <location filename="../defaultlook.ui" line="1038"/>
+        <source>TextLabel</source>
+        <translation>TextLabel</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1031"/>
+        <source>GTK scaling</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1058"/>
+        <source>xrandr Scaling</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1113"/>
         <source>Other</source>
         <translation>Другое</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="916"/>
+        <location filename="../defaultlook.ui" line="1121"/>
         <source>Enable single-click on desktop</source>
         <translation>Задействовать одиночный клик на рабочем столе</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="923"/>
+        <location filename="../defaultlook.ui" line="1128"/>
         <source>Enable single-click in Thunar File Manager</source>
         <translation>Задействовать одиночный клик в Thunar</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="960"/>
+        <location filename="../defaultlook.ui" line="1165"/>
         <source>Show systray (notification area) frame</source>
         <translation>Отображать рамку systray (область уведомлений)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="967"/>
+        <location filename="../defaultlook.ui" line="1172"/>
         <source>Show windows from all workspaces in panel</source>
         <translation>Показывать на панели окна со всех рабочих столов</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="974"/>
+        <location filename="../defaultlook.ui" line="1179"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation>Включить монтирование внешних носителей для не-рут пользователей</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="981"/>
+        <location filename="../defaultlook.ui" line="1186"/>
         <source>Disable shortening of long filenames on the desktop</source>
         <translation>Отключить укорачивание длинных имен на рабочем столе</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="988"/>
+        <location filename="../defaultlook.ui" line="1193"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation>Добавить hibernate в меню Выхода из системы</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="995"/>
+        <location filename="../defaultlook.ui" line="1200"/>
         <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation>примечание: для hibernate необходим swap &gt;= RAM</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="526"/>
+        <location filename="../defaultlook.cpp" line="535"/>
         <source>About MX Tweak</source>
         <translation>О MX Tweak</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="527"/>
+        <location filename="../defaultlook.cpp" line="536"/>
         <source>Version: </source>
         <translation>Версия: </translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="528"/>
+        <location filename="../defaultlook.cpp" line="537"/>
         <source>App for quick default ui theme changes and tweaks</source>
         <translation>Приложение для доводки штатного оформления и твиков</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="530"/>
+        <location filename="../defaultlook.cpp" line="539"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="531"/>
-        <location filename="../defaultlook.cpp" line="534"/>
+        <location filename="../defaultlook.cpp" line="540"/>
+        <location filename="../defaultlook.cpp" line="543"/>
         <source>License</source>
         <translation>Лицензия</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="532"/>
+        <location filename="../defaultlook.cpp" line="541"/>
         <source>Cancel</source>
         <translation>Отменить</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="563"/>
+        <location filename="../defaultlook.cpp" line="572"/>
         <source>Finished! Firefox may require a restart for changes to take effect</source>
         <translation>Готово! Может потребоваться перезапуск Firefox</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="573"/>
+        <location filename="../defaultlook.cpp" line="582"/>
         <source>This app is Xfce-only</source>
         <translation>Приложение только для Xfce</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="715"/>
+        <location filename="../defaultlook.cpp" line="724"/>
         <source>Panel settings</source>
         <translation>Настройки панели</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="716"/>
+        <location filename="../defaultlook.cpp" line="725"/>
         <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
-        <translation type="vanished">Текущие настройки панели были сохранены в скрытой папке .restore вашего домашнего каталога (~/.restore/)</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.cpp" line="1160"/>
+        <location filename="../defaultlook.cpp" line="1416"/>
         <source>Choose a theme set</source>
         <translation>Выберите набор темы</translation>
     </message>
@@ -436,7 +541,7 @@
     <message>
         <location filename="../remove_user_theme_set.ui" line="14"/>
         <source>Remove User Theme Set</source>
-        <translation type="unfinished"></translation>
+        <translation>Удалить набор тем пользователя</translation>
     </message>
 </context>
 <context>
@@ -444,12 +549,12 @@
     <message>
         <location filename="../theming_to_tweak.ui" line="14"/>
         <source>New Theme Set</source>
-        <translation type="unfinished"></translation>
+        <translation>Новая настройка темы</translation>
     </message>
     <message>
         <location filename="../theming_to_tweak.ui" line="20"/>
         <source>Enter name for new theme set</source>
-        <translation type="unfinished"></translation>
+        <translation>Введите имя для настройки темы</translation>
     </message>
 </context>
 <context>
