@@ -1,16 +1,65 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="sk">
+<context>
+    <name>brightness_small</name>
+    <message>
+        <location filename="../brightness_small.ui" line="14"/>
+        <source>MainWindow</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="39"/>
+        <source>Save</source>
+        <translation type="unfinished">Uložiť</translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="59"/>
+        <source>Software (xrandr) Brightness</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="66"/>
+        <location filename="../brightness_small.ui" line="87"/>
+        <source>TextLabel</source>
+        <translation type="unfinished">Textové označenie</translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="80"/>
+        <source>Hardware Backlight</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="94"/>
+        <source>&gt;&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.cpp" line="23"/>
+        <source>MX-Tweak</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.cpp" line="49"/>
+        <source>Display</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.cpp" line="54"/>
+        <source>&amp;Quit</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>defaultlook</name>
     <message>
         <location filename="../defaultlook.ui" line="20"/>
-        <location filename="../defaultlook.cpp" line="58"/>
-        <location filename="../defaultlook.cpp" line="527"/>
-        <location filename="../defaultlook.cpp" line="534"/>
-        <location filename="../defaultlook.cpp" line="551"/>
-        <location filename="../defaultlook.cpp" line="562"/>
-        <location filename="../defaultlook.cpp" line="572"/>
+        <location filename="../defaultlook.cpp" line="62"/>
+        <location filename="../defaultlook.cpp" line="536"/>
+        <location filename="../defaultlook.cpp" line="543"/>
+        <location filename="../defaultlook.cpp" line="560"/>
+        <location filename="../defaultlook.cpp" line="571"/>
+        <location filename="../defaultlook.cpp" line="581"/>
         <source>MX Tweak</source>
         <translation>MX Tweak</translation>
     </message>
@@ -145,7 +194,10 @@
         <location filename="../defaultlook.ui" line="549"/>
         <location filename="../defaultlook.ui" line="740"/>
         <location filename="../defaultlook.ui" line="894"/>
-        <location filename="../defaultlook.ui" line="936"/>
+        <location filename="../defaultlook.ui" line="974"/>
+        <location filename="../defaultlook.ui" line="1097"/>
+        <location filename="../defaultlook.ui" line="1104"/>
+        <location filename="../defaultlook.ui" line="1141"/>
         <source>Apply</source>
         <translation>Použiť</translation>
     </message>
@@ -187,6 +239,7 @@
     <message>
         <location filename="../defaultlook.ui" line="589"/>
         <source>Remove User Theme Set</source>
+        <oldsource>Remove User Theme Sets</oldsource>
         <translation>Odobrať užívateľskú sadu tém</translation>
     </message>
     <message>
@@ -200,16 +253,6 @@
         <source>Compositor</source>
         <translation>Kompozitor</translation>
     </message>
-    <message>
-        <location filename="../defaultlook.ui" line="635"/>
-        <source>Launch compton-conf configuration tool</source>
-        <translation>Spustiť konfiguračný nástroj compton-conf</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="638"/>
-        <source>Compton settings</source>
-        <translation>Compton nastavenia </translation>
-    </message>
     <message>
         <location filename="../defaultlook.ui" line="662"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
@@ -250,6 +293,16 @@
         <source>Transparency and shadow options</source>
         <translation>Možnosti priehľadnosti a tieňovania</translation>
     </message>
+    <message>
+        <location filename="../defaultlook.ui" line="635"/>
+        <source>Launch compton-conf configuration tool</source>
+        <translation>Spustiť konfiguračný nástroj compton-conf</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="638"/>
+        <source>Compton settings</source>
+        <translation>Compton nastavenia </translation>
+    </message>
     <message>
         <location filename="../defaultlook.ui" line="774"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
@@ -327,106 +380,158 @@
     </message>
     <message>
         <location filename="../defaultlook.ui" line="908"/>
+        <source>Display</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="933"/>
+        <source>Hardware Backlight</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="940"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="967"/>
+        <source>Choose Display for xrandr tweaks</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1000"/>
+        <source>Resolution</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1007"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1010"/>
+        <source>Save</source>
+        <translation>Uložiť</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1017"/>
+        <source>Software (xrandr) Brightness</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1024"/>
+        <location filename="../defaultlook.ui" line="1038"/>
+        <source>TextLabel</source>
+        <translation>Textové označenie</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1031"/>
+        <source>GTK scaling</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1058"/>
+        <source>xrandr Scaling</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1113"/>
         <source>Other</source>
         <translation>Iné</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="916"/>
+        <location filename="../defaultlook.ui" line="1121"/>
         <source>Enable single-click on desktop</source>
         <translation>Zapnúť spúšťanie jediným kliknutím na ploche</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="923"/>
+        <location filename="../defaultlook.ui" line="1128"/>
         <source>Enable single-click in Thunar File Manager</source>
         <translation>Zapnúť spúšťanie jediným kliknutím v Thunar-i</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="960"/>
+        <location filename="../defaultlook.ui" line="1165"/>
         <source>Show systray (notification area) frame</source>
         <translation>Zobraziť ohraničenie systray (oznamovacej oblasti)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="967"/>
+        <location filename="../defaultlook.ui" line="1172"/>
         <source>Show windows from all workspaces in panel</source>
         <translation>Na paneli zobrazovať okná zo všetkých pracovných plôch</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="974"/>
+        <location filename="../defaultlook.ui" line="1179"/>
         <source>Enable mounting of internal drives by non-root users</source>
         <translation>Povoliť pripájanie interných diskov užívateľom bez práv root-a</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="981"/>
+        <location filename="../defaultlook.ui" line="1186"/>
         <source>Disable shortening of long filenames on the desktop</source>
         <translation>Zakázať skracovanie názvov súborov na ploche</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="988"/>
+        <location filename="../defaultlook.ui" line="1193"/>
         <source>Enable hibernate on Log Out menu </source>
         <translation>V Odhlasovacom okne zapnuť voľbu Hibernovať</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="995"/>
+        <location filename="../defaultlook.ui" line="1200"/>
         <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
         <translation>POZOR: Pre Hibernáciu je potrebný SWAP &gt;= RAM</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="526"/>
+        <location filename="../defaultlook.cpp" line="535"/>
         <source>About MX Tweak</source>
         <translation>O programe MX Tweak</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="527"/>
+        <location filename="../defaultlook.cpp" line="536"/>
         <source>Version: </source>
         <translation>Verzia:</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="528"/>
+        <location filename="../defaultlook.cpp" line="537"/>
         <source>App for quick default ui theme changes and tweaks</source>
         <translation>Previesť rýchle zmeny v predvolených systémových motívoch</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="530"/>
+        <location filename="../defaultlook.cpp" line="539"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="531"/>
-        <location filename="../defaultlook.cpp" line="534"/>
+        <location filename="../defaultlook.cpp" line="540"/>
+        <location filename="../defaultlook.cpp" line="543"/>
         <source>License</source>
         <translation>Licencia</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="532"/>
+        <location filename="../defaultlook.cpp" line="541"/>
         <source>Cancel</source>
         <translation>Zrušiť</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="563"/>
+        <location filename="../defaultlook.cpp" line="572"/>
         <source>Finished! Firefox may require a restart for changes to take effect</source>
         <translation>Dokončené! Pred zavedením zmien môže byť potrebné reštartovať Firefox</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="573"/>
+        <location filename="../defaultlook.cpp" line="582"/>
         <source>This app is Xfce-only</source>
         <translation>Táto aplikácia je len pre Xfce</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="715"/>
+        <location filename="../defaultlook.cpp" line="724"/>
         <source>Panel settings</source>
         <translation>Nastavenia panelu</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="716"/>
+        <location filename="../defaultlook.cpp" line="725"/>
         <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
-        <translation type="vanished">Nastavenia panelu boli zazálohované do skrytej zložky s názvom .restore vo vašej home zložke (~/.restore/)</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.cpp" line="1160"/>
+        <location filename="../defaultlook.cpp" line="1416"/>
         <source>Choose a theme set</source>
         <translation>Vybrať motív</translation>
     </message>
