@@ -1,18 +1,67 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.1" language="sl">
+<context>
+    <name>brightness_small</name>
+    <message>
+        <location filename="../brightness_small.ui" line="14"/>
+        <source>MainWindow</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="39"/>
+        <source>Save</source>
+        <translation type="unfinished">Shrani</translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="59"/>
+        <source>Software (xrandr) Brightness</source>
+        <translation type="unfinished">Programska (xrandr) osvetlitev</translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="66"/>
+        <location filename="../brightness_small.ui" line="87"/>
+        <source>TextLabel</source>
+        <translation type="unfinished">TekstovnaOznaka</translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="80"/>
+        <source>Hardware Backlight</source>
+        <translation type="unfinished">Strojna ozadnja osvetlitev</translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.ui" line="94"/>
+        <source>&gt;&gt;</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.cpp" line="23"/>
+        <source>MX-Tweak</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.cpp" line="49"/>
+        <source>Display</source>
+        <translation type="unfinished">Zaslon</translation>
+    </message>
+    <message>
+        <location filename="../brightness_small.cpp" line="54"/>
+        <source>&amp;Quit</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>defaultlook</name>
     <message>
         <location filename="../defaultlook.ui" line="20"/>
-        <location filename="../defaultlook.cpp" line="58"/>
-        <location filename="../defaultlook.cpp" line="527"/>
-        <location filename="../defaultlook.cpp" line="534"/>
-        <location filename="../defaultlook.cpp" line="551"/>
-        <location filename="../defaultlook.cpp" line="562"/>
-        <location filename="../defaultlook.cpp" line="572"/>
+        <location filename="../defaultlook.cpp" line="62"/>
+        <location filename="../defaultlook.cpp" line="536"/>
+        <location filename="../defaultlook.cpp" line="543"/>
+        <location filename="../defaultlook.cpp" line="560"/>
+        <location filename="../defaultlook.cpp" line="571"/>
+        <location filename="../defaultlook.cpp" line="581"/>
         <source>MX Tweak</source>
-        <translation>MX friziranje</translation>
+        <translation>MX Prilagoditve</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="54"/>
@@ -145,7 +194,10 @@
         <location filename="../defaultlook.ui" line="549"/>
         <location filename="../defaultlook.ui" line="740"/>
         <location filename="../defaultlook.ui" line="894"/>
-        <location filename="../defaultlook.ui" line="936"/>
+        <location filename="../defaultlook.ui" line="974"/>
+        <location filename="../defaultlook.ui" line="1097"/>
+        <location filename="../defaultlook.ui" line="1104"/>
+        <location filename="../defaultlook.ui" line="1141"/>
         <source>Apply</source>
         <translation>Potrdi</translation>
     </message>
@@ -167,7 +219,7 @@
     <message>
         <location filename="../defaultlook.ui" line="516"/>
         <source>Firefox dark theme tweak</source>
-        <translation>Sfrizirana temna tema za Firefox</translation>
+        <translation>Prilagojena temna tema za Firefox</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="523"/>
@@ -187,12 +239,13 @@
     <message>
         <location filename="../defaultlook.ui" line="589"/>
         <source>Remove User Theme Set</source>
+        <oldsource>Remove User Theme Sets</oldsource>
         <translation>Odstranite uporabnikov tematski set</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="600"/>
         <source>Save Current Settings as a Theme Set</source>
-        <translation>Sharni trenutne nastavitve kot tematski set</translation>
+        <translation>Shrani trenutne nastavitve kot tematski set</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="614"/>
@@ -200,16 +253,6 @@
         <source>Compositor</source>
         <translation>Kompozitor</translation>
     </message>
-    <message>
-        <location filename="../defaultlook.ui" line="635"/>
-        <source>Launch compton-conf configuration tool</source>
-        <translation>Zaženi compton-conf konfiguracijsko orodje</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.ui" line="638"/>
-        <source>Compton settings</source>
-        <translation>Compton nastavitve</translation>
-    </message>
     <message>
         <location filename="../defaultlook.ui" line="662"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Xfce Compositor Settings&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
@@ -250,6 +293,16 @@
         <source>Transparency and shadow options</source>
         <translation>Opcije za prosojnost in sence</translation>
     </message>
+    <message>
+        <location filename="../defaultlook.ui" line="635"/>
+        <source>Launch compton-conf configuration tool</source>
+        <translation>Zaženi compton-conf konfiguracijsko orodje</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="638"/>
+        <source>Compton settings</source>
+        <translation>Compton nastavitve</translation>
+    </message>
     <message>
         <location filename="../defaultlook.ui" line="774"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Changing the VBlank mode may help alleviate some screen tearing issues.  See Help for more information.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
@@ -278,7 +331,7 @@
     <message>
         <location filename="../defaultlook.ui" line="800"/>
         <source>off</source>
-        <translation>izklop</translation>
+        <translation>izklopljeno</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="811"/>
@@ -293,7 +346,7 @@
     <message>
         <location filename="../defaultlook.ui" line="826"/>
         <source>Reset Thunar custom right-click actions to system defaults</source>
-        <translation>Ponastavi Thunarjeve uporabniške akcije ob desnem kliku na sistemsko privzete</translation>
+        <translation>V Thunarju ponastavi po meri določena dejanja z desnim klikom na sistemsko privzete</translation>
     </message>
     <message>
         <location filename="../defaultlook.ui" line="833"/>
@@ -327,106 +380,158 @@
     </message>
     <message>
         <location filename="../defaultlook.ui" line="908"/>
+        <source>Display</source>
+        <translation>Zaslon</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="933"/>
+        <source>Hardware Backlight</source>
+        <translation>Strojna ozadnja osvetlitev</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="940"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Display Tweaks&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Zaslonske prilagoditve&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="967"/>
+        <source>Choose Display for xrandr tweaks</source>
+        <translation>Izberite prikaz za xrandr prilagoditve</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1000"/>
+        <source>Resolution</source>
+        <translation>Ločljivost</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1007"/>
+        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Saving is per display&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Shranjevanje za vsak zaslon&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1010"/>
+        <source>Save</source>
+        <translation>Shrani</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1017"/>
+        <source>Software (xrandr) Brightness</source>
+        <translation>Programska (xrandr) osvetlitev</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1024"/>
+        <location filename="../defaultlook.ui" line="1038"/>
+        <source>TextLabel</source>
+        <translation>TekstovnaOznaka</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1031"/>
+        <source>GTK scaling</source>
+        <translation>GTK prilagajanje velikosti</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1058"/>
+        <source>xrandr Scaling</source>
+        <translation>xrandr prilagajanje velikosti</translation>
+    </message>
+    <message>
+        <location filename="../defaultlook.ui" line="1113"/>
         <source>Other</source>
         <translation>Drugo</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="916"/>
+        <location filename="../defaultlook.ui" line="1121"/>
         <source>Enable single-click on desktop</source>
         <translation>Vklopi enojni klik na namizju</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="923"/>
+        <location filename="../defaultlook.ui" line="1128"/>
         <source>Enable single-click in Thunar File Manager</source>
-        <translation>Vklopi enojni klik nv Thunar upravljalniku datotek</translation>
+        <translation>Vklopi enojni klik v Thunar upravljalniku datotek</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="960"/>
+        <location filename="../defaultlook.ui" line="1165"/>
         <source>Show systray (notification area) frame</source>
         <translation>Prikaži sistemsko pasico (področje za obvestila)</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="967"/>
+        <location filename="../defaultlook.ui" line="1172"/>
         <source>Show windows from all workspaces in panel</source>
         <translation>V panoju prikaži okna iz vseh delovnih površin</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="974"/>
+        <location filename="../defaultlook.ui" line="1179"/>
         <source>Enable mounting of internal drives by non-root users</source>
-        <translation>Vključi priklapljanje internih pogonov za nekorenske uporabnike</translation>
+        <translation>Omogoči priklop internih pogonov ne-korenskim uporabnikom</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="981"/>
+        <location filename="../defaultlook.ui" line="1186"/>
         <source>Disable shortening of long filenames on the desktop</source>
-        <translation>Izklopi skrajševanje dolgih imen datotek na namizju</translation>
+        <translation>Izklopi krajšanje dolgih imen datotek na namizju</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="988"/>
+        <location filename="../defaultlook.ui" line="1193"/>
         <source>Enable hibernate on Log Out menu </source>
-        <translation>Vklopi hibernacijo v meniju za odjavo</translation>
+        <translation>V odjavnem meniju omogoči hibernacijo</translation>
     </message>
     <message>
-        <location filename="../defaultlook.ui" line="995"/>
+        <location filename="../defaultlook.ui" line="1200"/>
         <source>                   note: to hibernate, swap needs to be &gt;= RAM</source>
-        <translation>pomni: za hibernacijo mora biti swap &gt;= RAM</translation>
+        <translation>opomba: za hibernacijo mora biti velikost razdelka swap &gt;= RAM</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="526"/>
+        <location filename="../defaultlook.cpp" line="535"/>
         <source>About MX Tweak</source>
         <translation>O MX fiziranju</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="527"/>
+        <location filename="../defaultlook.cpp" line="536"/>
         <source>Version: </source>
         <translation>Različica:</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="528"/>
+        <location filename="../defaultlook.cpp" line="537"/>
         <source>App for quick default ui theme changes and tweaks</source>
-        <translation>Aplikacija za hitro spreminjanje in friziranje privezete teme uporabniškega vmesnika</translation>
+        <translation>Aplikacija za hitro spreminjanje in prilagajanje privzete teme uporabniškega vmesnika</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="530"/>
+        <location filename="../defaultlook.cpp" line="539"/>
         <source>Copyright (c) MX Linux</source>
         <translation>Copyright (c) MX Linux</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="531"/>
-        <location filename="../defaultlook.cpp" line="534"/>
+        <location filename="../defaultlook.cpp" line="540"/>
+        <location filename="../defaultlook.cpp" line="543"/>
         <source>License</source>
         <translation>Licenca</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="532"/>
+        <location filename="../defaultlook.cpp" line="541"/>
         <source>Cancel</source>
         <translation>Prekliči</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="563"/>
+        <location filename="../defaultlook.cpp" line="572"/>
         <source>Finished! Firefox may require a restart for changes to take effect</source>
         <translation>Končano! Firefox bo morda potreboval ponovni zagon, da bodo spremembe delovale.</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="573"/>
+        <location filename="../defaultlook.cpp" line="582"/>
         <source>This app is Xfce-only</source>
         <translation>Ta aplikacija je zgolj Xfce</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="715"/>
+        <location filename="../defaultlook.cpp" line="724"/>
         <source>Panel settings</source>
         <translation>Nastavitve panoja</translation>
     </message>
     <message>
-        <location filename="../defaultlook.cpp" line="716"/>
+        <location filename="../defaultlook.cpp" line="725"/>
         <source>Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
-        <translation type="unfinished"></translation>
+        <translation>Trenutne nastavitve orodne vrstice so se shranile v skrito mapo z imenom .restore  znotraj uporabniske domace mape (~/.restore/)</translation>
     </message>
     <message>
-        <source> Your current panel settings have been backed up in a hidden folder called .restore in your home folder (~/.restore/)</source>
-        <translation type="vanished">Vaše trenutne nastavitve panoja so bile varnostno skopirane v skrito mapo z imenom .restore v vaši domači home mapi (~/.restore/)</translation>
-    </message>
-    <message>
-        <location filename="../defaultlook.cpp" line="1160"/>
+        <location filename="../defaultlook.cpp" line="1416"/>
         <source>Choose a theme set</source>
         <translation>Izberite tematski set</translation>
     </message>
@@ -498,7 +603,7 @@
     <message>
         <location filename="../window_buttons.ui" line="74"/>
         <source>Window Title</source>
-        <translation>Naslov okna</translation>
+        <translation>Naziv okna</translation>
     </message>
     <message>
         <location filename="../window_buttons.ui" line="79"/>
